# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


from django.contrib import admin
from django.conf.urls.defaults import patterns
from django.views.generic.simple import direct_to_template
from django.http import HttpResponse
from django.shortcuts import redirect
from django.contrib import messages


from feincms.translations import admin_translationinline, short_language_code

from cloudcms import models


class ApplicationAdmin(admin.ModelAdmin):
    raw_id_fields = ('logo', 'favicon')


class ClientVersionSourceAdminInline(admin.StackedInline):
    model = models.ClientVersionSource
    raw_id_fields = ('logo',)
    extra = 1


class ClientAdmin(admin.ModelAdmin):
    inlines = [ClientVersionSourceAdminInline]


ServiceTranslationInline = admin_translationinline(models.ServiceTranslation,
        prepopulated_fields={'slug': ('title',)})

class ServiceAdmin(admin.ModelAdmin):
    inlines = [ServiceTranslationInline]


admin.site.register(models.Application, ApplicationAdmin)
admin.site.register(models.Client, ClientAdmin)
admin.site.register(models.Service, ServiceAdmin)


from cloudcms.forms import RstZipImportForm

def import_from_sphinx(request):
    if not request.user.is_superuser:
        return HttpResponse(status=401)

    context = {}
    form = RstZipImportForm()

    if request.GET.get('form_saved'):
        context['save_log'] = request.session.get('save_log')
    else:
        if request.session.get('save_log'):
            del request.session['save_log']

    if request.method == 'POST':
        form = RstZipImportForm(request.POST, request.FILES)
        if form.is_valid():
            try:
                saved, log = form.save(request.user)
                if saved:
                    messages.add_message(request, messages.INFO, 'Form saved')
                    request.session['save_log'] = log.replace("\n", "<br />")
                    return redirect('/cmsmanage/rstimport/' + '?form_saved=1')
                else:
                    messages.add_message(request, messages.ERROR, 'Form failed')
                    context['save_log'] = log.replace("\n", "<br />")
            except Exception, e:
                context['save_log'] = e

        else:
            context['error'] = True

    context['form'] = form

    return direct_to_template(request, 'cms/admin_import_guide_faq.html', context)

sphinx_import = admin.site.admin_view(import_from_sphinx)

