# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


import mptt

from django import forms
from django.db import models
from django.utils.text import capfirst
from django.utils.translation import ugettext_lazy as _

from feincms.module.page.models import Page
from feincms.content.raw.models import RawContent
from feincms.content.richtext.models import RichTextContent
from feincms.content.image.models import ImageContent
from feincms.content.application.models import ApplicationContent
from feincms.module.page.extensions.navigation import NavigationExtension, \
        PagePretender
from feincms.content.application.models import reverse
from feincms.content.medialibrary.v2 import MediaFileContent
from feincms.content.section.models import SectionContent
from feincms.content.table.models import TableContent
from feincms.content.template.models import TemplateContent
from feincms.content.video.models import VideoContent
from feincms.content.richtext.models import RichTextContent

from cloudcmsresources.models import ResourcesList
from cloudcms.content import *


Page.register_extensions(
    'changedate',
    'datepublisher',
    'translations',
    'seo',
    'symlinks',
    'navigation',
    'sites',
    'titles',
    'featured',
)


# Feincms Page templates declaration
TEMPLATES = [{
    'key': 'twocolwide',
    'title': 'Basic 2 columns template (left wider)',
    'path': 'cms/pages/twocolwide.html',
    'regions': (
        ('main', 'Main region'),
        ('sidebar', 'Sidebar', 'inherited'),
        ),
    },
    {
    'key': 'singlecol',
    'title': 'Basic (Top 1 col, Bottom 2 cols)',
    'path': 'cms/pages/basic1top2bottom.html',
    'regions': (
        ('top', 'Top region'),
        ('bottom_left', 'Bottom left region'),
        ('bottom_right', 'Bottom right region'),
        ),
    },
             {
    'key': 'basic2top2bottom',
    'title': 'Basic (Top 2 cols, Bottom 2 cols)',
    'path': 'cms/pages/basic2top2bottom.html',
    'regions': (
        ('top_left', 'Top left region'),
        ('top_right', 'Top right region'),
        ('bottom_left', 'Bottom left region'),
        ('bottom_right', 'Bottom right region'),
        ),
    },
    {
    'key': 'blog',
    'title': 'Blog template',
    'path': 'cms/pages/blog.html',
    'regions': (
        ('main', 'Main region'),
        ('sidebar', 'Sidebar', 'inherited'),
        ),
    },
    {
    'key': 'userguide',
    'title': 'Userguide template',
    'path': 'cms/pages/userguide.html',
    'regions': (
        ('top', 'Top region'),
        ('bottom_left', 'Bottom left region'),
        ('bottom_right', 'Bottom right region'),
        ),
    },
    {
    'key': 'faq',
    'title': 'FAQ\'s template',
    'path': 'cms/pages/faq.html',
    'regions': (
        ('top', 'Top region'),
        ('bottom_left', 'Bottom left region'),
        ('bottom_right', 'Bottom right region'),
        ),
    },
    {
    'key': 'raw',
    'title': 'Empty content template',
    'path': 'cms/pages/empty.html',
    'regions': (
        ('main', 'Main region'),
        ),
    },
    {
    'key': 'topwidetwocol',
    'title': 'Basic (Top 1 col, Middle 2 cols, Bottom 2 cols)',
    'path': 'cms/pages/topwidetwocol.html',
    'regions': (
        ('top', 'Top region'), 
        ('middle_left', 'Middle left region'),
        ('middle_right', 'Middle right region'),
        ('bottom_left', 'Bottom left region'),
        ('bottom_right', 'Bottom right region'),
        ),
    },
]

# register templates
map(Page.register_templates, TEMPLATES)

Page.create_content_type(TextileContent)
Page.create_content_type(IntroBlock)
Page.create_content_type(RichTextContent)
Page.create_content_type(RawContent)
Page.create_content_type(SectionContent, TYPE_CHOICES=(('block', 'Block'),))
Page.create_content_type(TemplateContent)
Page.create_content_type(TwitterFeed)
Page.create_content_type(VideoContent)
Page.create_content_type(VideoSection)
Page.create_content_type(IntroButton)
Page.create_content_type(ClientDownload)
Page.create_content_type(ImageContent, POSITION_CHOICES=(
    ('default', 'Default position'),
))
Page.create_content_type(MediaFileContent, TYPE_CHOICES=(
  ('lightbox', 'lightbox'),
  ('download', 'as download')
))
Page.create_content_type(ApplicationContent, APPLICATIONS=(
    ('cloudcmsblog', 'Cloud blog', {'urls': 'cloudcmsblog.urls'}),
    ('cloudcmsfaq', 'Cloud FAQ', {'urls': 'cloudcmsfaq.urls'}),
    ('cloudcmsguide', 'Cloud user guide', {'urls': 'cloudcmsguide.urls'}),)
)

# cloudcms specific content registration
Page.create_content_type(LoginForm)
Page.create_content_type(AboutBlock)
Page.create_content_type(ResourcesList)
Page.create_content_type(BlockColor)

# Extra cms applications
EXTRA_CONTENT_MODELS = []

if 'cloudcmsblog' in settings.INSTALLED_APPS:
    from cloudcmsblog.models import Entry, LatestEntries
    EXTRA_CONTENT_MODELS.append(Entry)
    Page.create_content_type(LatestEntries)

if 'cloudcmsfaq' in settings.INSTALLED_APPS:
    from cloudcmsfaq.models import Question
    EXTRA_CONTENT_MODELS.append(Question)

if 'cloudcmsguide' in settings.INSTALLED_APPS:
    from cloudcmsguide.models import UserGuideEntry
    EXTRA_CONTENT_MODELS.append(UserGuideEntry)

for model in EXTRA_CONTENT_MODELS:
    # Feincms specific registrations for our blog entry model
    model.register_regions(
        ('main', _('Main content area')),
        ('sidebar', _('Right column')),
    )
    model.create_content_type(RawContent)
    model.create_content_type(TemplateContent)
    model.create_content_type(SectionContent, TYPE_CHOICES=(('block', 'Block'),))
    model.create_content_type(RichTextContent, cleanse=False, regions=('main',))
    model.create_content_type(ImageContent, POSITION_CHOICES=(
        ('default', 'Default position'),
    ))


Page.create_content_type(StatsBlock)
Page.create_content_type(IntroVideo)