# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


from django.conf import settings
from django.contrib.syndication.views import Feed

from cloudcmsblog.models import Entry
from cloudcms.models import Application


BLOG_FEED_ENTRIES_LIMIT = getattr(settings, 'CLOUDCMSBLOG_FEED_ENTRIES_LIMIT',
                            10)
BLOG_FEED_TITLE = getattr(settings, 'CLOUDCMSBLOG_FEED_TITLE',
                            "Latest blog posts")
BLOG_FEED_LINK = getattr(settings, 'CLOUDCMSBLOG_FEED_LINK',
                            "/feed/")
BLOG_FEED_DESCRIPTION = getattr(settings, 'CLOUDCMSBLOG_FEED_DESCRIPTION',
                            BLOG_FEED_TITLE)

class BlogFeed(Feed):
    title = BLOG_FEED_TITLE
    link = BLOG_FEED_LINK
    description = BLOG_FEED_DESCRIPTION

    def __init__(self, *args, **kwargs):
        pass

    def items(self):
        return Entry.objects.order_by('-published_on')[:BLOG_FEED_ENTRIES_LIMIT]

    def item_title(self, item):
        return item.title

    def item_description(self, item):
        return item.intro_text

    def item_pubdate(self, item):
        return item.published_on

