# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


from django.conf import settings
from django.views.generic.simple import direct_to_template
from django.http import HttpResponseRedirect, Http404
from django.shortcuts import get_object_or_404

from cloudcms.models import Application
from cloudcmsblog.models import Entry, Category, CategoryTranslation, get_blog_page

def index(request):
    """
    Redirecto to first category found entries archive
    """
    categories = Category.objects.filter(display_on_menu=True)
    if categories.exists() == 0:
        raise Http404
    
    app_page_url = get_blog_page().get_navigation_url()
    try:
        default_category_url = categories[0].get_absolute_url()
    except IndexError:
        raise Http404

    return HttpResponseRedirect("%s%s" % (app_page_url.rstrip("/"), default_category_url))


def archive(request, category):
    """
    Display entries list
    """
    app = Application.current()
    category = get_object_or_404(Category, translations__slug=category)
    entries = category.blogentries.all()
    return direct_to_template(request,
            "cloudcmsblog/archive.html", {'entries': entries,
                'ENTRIES_PER_PAGE': getattr(settings,
                    'CLOUDCMSBLOG_ENTRIES_PER_PAGE', 2)})


def detail(request, year, month, day, slug):
    """
    Display detailed blog entry.
    """
    entry = get_object_or_404(Entry, published_on__year=year,
            published_on__month=month, published_on__day=day,
            slug=slug, is_active=True)
    return direct_to_template(request,
            "cloudcmsblog/detail.html", {'entry': entry})
