# Copyright 2012 GRNET S.A. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
#   1. Redistributions of source code must retain the above
#      copyright notice, this list of conditions and the following
#      disclaimer.
#
#   2. Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials
#      provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# The views and conclusions contained in the software and
# documentation are those of the authors and should not be
# interpreted as representing official policies, either expressed
# or implied, of GRNET S.A.


from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from feincms.translations import admin_translationinline, short_language_code
from feincms.admin import tree_editor, item_editor

from cloudcmsguide.models import UserGuideEntry


class UserGuideEntryAdmin(item_editor.ItemEditor, tree_editor.TreeEditor):

    date_hierarchy = 'published_on'
    list_display = ['title', 'is_active', 'published_on', 'service', 'author']
    list_editable = ['is_active']
    list_filter = ['is_active', 'is_featured', 'author']
    search_fields = ['title', 'slug']
    raw_id_fields = ['parent']

    prepopulated_fields = {
        'slug': ('title',),
        }

    fieldsets = [
        [None, {
            'fields': [
                ('is_active', 'published_on'),
                ('title', 'slug'),
                'parent',
                'service',
                'author',
            ]
        }],
        item_editor.FEINCMS_CONTENT_FIELDSET,
    ]

    def import_from_sphinx(self, request):
        return import_from_sphinx(request)


admin.site.register(UserGuideEntry, UserGuideEntryAdmin)

