from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from cloudcmsresources.models import ResourceCategory, \
    ResourceCategoryTranslation, Resource, ResourceTranslation
from feincms.translations import admin_translationinline, short_language_code
from feincms.admin import item_editor

CategoryTranslationInline = admin_translationinline(ResourceCategoryTranslation,
        prepopulated_fields={'slug': ('title',)})
ResourceTranslationInline = admin_translationinline(ResourceTranslation,
        prepopulated_fields={'slug': ('title',)})

class ResourceCategoryAdmin(admin.ModelAdmin):
    inlines = [CategoryTranslationInline]
    list_display = ['__unicode__', 'entries']
    search_fields = ['translations__title']

    def entries(self, obj):
        if 'translations' in getattr(ResourceCategory, '_feincms_extensions', ()):
            return ResourceCategory.objects.filter(translations=obj, language=short_language_code()).count()
        return ResourceCategory.objects.filter(translations=obj)

    entries.short_description = _('Blog entries in category')

class ResourceAdmin(admin.ModelAdmin):
    inlines = [ResourceTranslationInline]
    list_display = ['__unicode__', 'category', 'is_published', 'published_on']
    list_editable = ['published_on']
    raw_id_fields = ['media_file']


admin.site.register(Resource, ResourceAdmin)
admin.site.register(ResourceCategory, ResourceCategoryAdmin)

