from datetime import datetime

from django.db import models
from django.conf import settings
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _, ugettext, ungettext
from django.template.loader import render_to_string
from django.core import urlresolvers
from django import forms

from feincms import translations
from feincms.models import Base
from feincms.module.page.models import Page
from feincms.content.richtext.models import RichTextContent
from feincms.content.section.models import SectionContent
from feincms.content.application.models import reverse
from feincms.module.medialibrary.fields import MediaFileForeignKey
from feincms.module.medialibrary.models import MediaFile
from feincms.module.page.extensions.navigation import NavigationExtension
from feincms.module.page.extensions.navigation import PagePretender
from feincms.content.application.models import ApplicationContent

from cloudcms.models import Application
from cloudcms.cms_utils import get_app_page

from feincms import translations
from feincms.models import Base
from feincms.module.page.models import Page
from feincms.content.richtext.models import RichTextContent
from feincms.content.section.models import SectionContent
from feincms.content.application.models import reverse
from feincms.module.medialibrary.fields import MediaFileForeignKey
from feincms.module.medialibrary.models import MediaFile
from feincms.module.page.extensions.navigation import NavigationExtension
from feincms.module.page.extensions.navigation import PagePretender
from feincms.content.application.models import ApplicationContent

from cloudcms.models import Application
from cloudcms.cms_utils import get_app_page

# monkeypatch django reverse (feincms 1.5+ solves this issue)
urlresolvers.reverse = reverse


class ResourceCategory(models.Model, translations.TranslatedObjectMixin):
    ordering = models.SmallIntegerField(_('ordering'), default=0)
    display_on_menu = models.BooleanField(default=True)
    color = models.CharField(max_length=255, default="#FAAF40")

    class Meta:
        verbose_name = _('Resource category')
        verbose_name_plural = _('Resource categories')
        ordering = ['-ordering',]

    objects = translations.TranslatedObjectManager()

    def get_css_class(self):
        return "resource-cat-%d" % self.pk

    def get_css_def(self):
        return """
        .%(cls)s.resource { border-color: %(color)s !important;}
        .%(cls)s.resource .title { color: %(color)s !important;}
        .%(cls)s.resource .description { background-color: %(color)s !important;}
        .%(cls)s.filter-item a { color: %(color)s !important;}
        """ % dict(cls=self.get_css_class(), color=self.get_color())

    def get_color(self):
        return "#" + self.color.lstrip("#")

    def __unicode__(self):
        trans = translations.TranslatedObjectMixin.__unicode__(self)
        return trans or _('Unnamed resource category')


class ResourceCategoryTranslation(translations.Translation(ResourceCategory)):
    """
    Category translation
    """
    title = models.CharField(_('category title'), max_length=100)
    slug = models.SlugField(_('slug'), unique=True)
    description = models.TextField(_('description'), blank=True)

    class Meta:
        verbose_name = _('Resource category translation')
        verbose_name_plural = _('Resource category translations')
        ordering = ['title']

    def __unicode__(self):
        return self.title

    def save(self, *args, **kwargs):
        if not self.slug:
            self.slug = slugify(self.title)

        super(ResourceCategoryTranslation, self).save(*args, **kwargs)


class Resource(models.Model, translations.TranslatedObjectMixin):
    is_published = models.BooleanField(default=True)
    published_on = models.DateTimeField(default=datetime.now)

    ordering = models.SmallIntegerField(_('ordering'), default=0)
    category = models.ForeignKey(ResourceCategory)
    media_file = MediaFileForeignKey(MediaFile, null=False, blank=False)
    filetype = models.CharField(max_length=255, null=True, blank=True,
                                default="PDF")

    class Meta:
        verbose_name = _('Resource')
        verbose_name_plural = _('Resources')
        ordering = ['-ordering',]

    objects = translations.TranslatedObjectManager()

    def __unicode__(self):
        trans = translations.TranslatedObjectMixin.__unicode__(self)
        return trans or _('Unnamed resource')

    def get_filetype(self):
        return self.filetype

    def get_html_id(self):
        return "resource-obj-%d" % self.pk


class ResourceTranslation(translations.Translation(Resource)):
    """
    Category translation
    """
    title = models.CharField(_('resource title'), max_length=100)
    slug = models.SlugField(_('slug'), unique=True)
    description = models.TextField(_('description'), blank=True)

    class Meta:
        verbose_name = _('Resource translation')
        verbose_name_plural = _('Resource translations')
        ordering = ['title']

    def __unicode__(self):
        return self.title

    def save(self, *args, **kwargs):
        if not self.slug:
            self.slug = slugify(self.title)

        super(ResourceTranslation, self).save(*args, **kwargs)




# Feincms content abstract models
class ResourcesList(models.Model):
    filter_title = models.CharField(max_length=255)

    class Meta:
        abstract = True
        verbose_name = _('Resources list')
        verbose_name_plural = _('Resources lists')

    @property
    def media(self):
        return forms.Media(js=(
                settings.MEDIA_URL + 'cloudcmsresources/js/resources_list.js',
            ))

    def render(self, **kwargs):
        resources = Resource.objects.filter(published_on__lte=datetime.now(),
                is_published=True).order_by('-published_on')

        categories = ResourceCategory.objects.filter(display_on_menu=True)

        context = {'resources': resources, 'categories': categories,
                'content': self, 'MEDIA_URL': settings.MEDIA_URL}
        return render_to_string(['content/resources_list.html'], context)

